==> scm-helper-1.1.tar.gz: scm-helper-1.1/README.md <==
# SCM-Helper
Helper tool for [Swim Club Manager](https://www.swimclubmanager.co.uk/).

Download latest [Windows Version](https://github.com/ColinRobbins/scm-helper/raw/master/download/scm.zip).
# Features
* Works on Windows or Linux
* [Windows](https://github.com/ColinRobbins/scm-helper/wiki/windows) GUI
* [Backup and Restore](https://github.com/ColinRobbins/scm-helper/wiki/Backup-and-Restore) of SCM data
* Verification of member detail
* Check session and group consistency
* Check consistency of [Swim England](https://github.com/ColinRobbins/scm-helper/wiki/Swim-England) registrations with SE file
* Check [Facebook](https://github.com/ColinRobbins/scm-helper/wiki/Facebook) group members are club members
* Automatic [fixing](https://github.com/ColinRobbins/scm-helper/wiki/Fixing) of some errors
* Generation of [email lists](https://github.com/ColinRobbins/scm-helper/wiki/Email-Lists) based on group/class/gender/age
* Report on DBS and Safeguarding issue
* Report on swimmers not attending
* Report on swimmers whose confirmation of details has expired
* Fully [configurable](https://github.com/ColinRobbins/scm-helper/wiki/Configuration) (without programming skills)
# Documentation
See [documentation](https://github.com/ColinRobbins/scm-helper/wiki) on GitHub for installation and usage instructions. 
# Change Log
See [changelog](CHANGELOG.md)
# Donations.
The software was developed for free during 2020 lockdown, taking about 100 hours work.  If you find the software useful, please consider making a [donation](https://uk.virginmoneygiving.com/ColinRobbins) to support the NHS Covid 19 appeal.
## Author
* [Colin Robbins](https://github.com/ColinRobbins)

==> scm-helper-1.2.tar.gz: scm-helper-1.2/README.md <==
# SCM-Helper
Helper tool for [Swim Club Manager](https://www.swimclubmanager.co.uk/).

Download latest [Windows Version](https://github.com/ColinRobbins/scm-helper/raw/master/download/scm.zip).
# Features
* Works on Windows, Linux or Apple devices
* [Backup and Restore](https://github.com/ColinRobbins/scm-helper/wiki/Backup-and-Restore) of SCM data
* Verification of member details
* Check session and group consistency
* Check consistency of [Swim England](https://github.com/ColinRobbins/scm-helper/wiki/Swim-England) registrations
* Check [Facebook](https://github.com/ColinRobbins/scm-helper/wiki/Facebook) group members are club members
* Automatic [fixing](https://github.com/ColinRobbins/scm-helper/wiki/Fixing) of some errors
* Generation of swimming [records](Records)
* Generation of [email lists](https://github.com/ColinRobbins/scm-helper/wiki/Email-Lists) based on group/class/gender/age
* Report on DBS and Safeguarding issue
* Report on swimmers not attending
* Report on swimmers whose confirmation of details has expired
* Fully [configurable](https://github.com/ColinRobbins/scm-helper/wiki/Configuration) (without programming skills)
# Documentation
See [documentation](https://github.com/ColinRobbins/scm-helper/wiki) on GitHub for installation and usage instructions.
# Change Log
See [changelog](CHANGELOG.md)
# Donations.
The software was developed for free during 2020 lockdown, taking about 100 hours work.  If you find the software useful, please consider making a [donation](https://uk.virginmoneygiving.com/ColinRobbins) to support the NHS Covid 19 appeal.
## Author
* [Colin Robbins](https://github.com/ColinRobbins)
